@@ -12,6 +12,7 @@ from docutils.nodes import NodeVisitor
 from sphinx.application import Sphinx
 from sphinx.builders.text import TextBuilder
 from sphinx.util.typing import ExtensionMetadata
+from sphinx_toolbox.collapse import CollapseNode
 from ultimate_notion import Emoji
 from ultimate_notion.blocks import BulletedItem as UnoBulletedItem
 from ultimate_notion.blocks import Callout as UnoCallout
@@ -35,16 +36,16 @@ from ultimate_notion.blocks import (
 from ultimate_notion.blocks import (
     TableOfContents as UnoTableOfContents,
 )
+from ultimate_notion.blocks import (
+    ToggleItem as UnoToggleItem,
+)
 from ultimate_notion.core import NotionObject
 from ultimate_notion.obj_api.core import GenericObject
 from ultimate_notion.obj_api.enums import CodeLang, Color
 from ultimate_notion.rich_text import Text, text
 
 
-def _process_list_item_recursively(
-    node: nodes.list_item,
-    depth: int,
-) -> UnoBulletedItem:
+def _process_list_item_recursively(node: nodes.list_item) -> UnoBulletedItem:
     """
     Recursively process a list item node and return a BulletedItem.
     """
@@ -57,24 +58,6 @@ def _process_list_item_recursively(
     bullet_only_msg = (
         "The only thing Notion supports within a bullet list is a bullet list"
     )
-    max_notion_depth = 1
-    if depth >= max_notion_depth:
-        # This limit is described in https://developers.notion.com/reference/patch-block-children
-        #
-        # "For blocks that allow children, we allow up to two levels of
-        # nesting in a single request."
-        #
-        # Note that the top level bullet-list is the "child" of the "body"
-        # so there is really only one level of nesting in the Notion API
-        # in one request.
-        for child in node.children[1:]:
-            assert isinstance(child, nodes.bullet_list), bullet_only_msg
-            max_levels = max_notion_depth + 1
-            msg = (
-                f"Nested bullet point at depth {max_levels + 1} "
-                f"exceeds Notion API limit of {max_levels} levels."
-            )
-            raise ValueError(msg)
 
     for child in node.children[1:]:
         assert isinstance(child, nodes.bullet_list), bullet_only_msg
@@ -84,10 +67,10 @@ def _process_list_item_recursively(
             )
             nested_block = _process_list_item_recursively(
                 node=nested_list_item,
-                depth=depth + 1,
             )
             # Remove pyright ignore once we have
             # https://github.com/ultimate-notion/ultimate-notion/issues/94.
+            # pylint: disable=line-too-long
             block.obj_ref.value.children.append(nested_block.obj_ref)  # pyright: ignore[reportUnknownMemberType]
 
     return block
@@ -187,15 +170,6 @@ def _(
     return [code_block]
 
 
-@_process_node_to_blocks.register
-def _(node: nodes.list_item, *, section_level: int) -> list[NotionObject[Any]]:
-    """
-    Process list item nodes by creating BulletedItem blocks.
-    """
-    del section_level
-    return [_process_list_item_recursively(node=node, depth=0)]
-
-
 @_process_node_to_blocks.register
 def _(
     node: nodes.bullet_list,
@@ -206,10 +180,11 @@ def _(
     Process bullet list nodes by creating Notion BulletedItem blocks.
     """
     del section_level
-    del node
-    # We don't create a block for the list itself,
-    # just process the children (list items)
-    return []
+    return [
+        _process_list_item_recursively(node=list_item)
+        for list_item in node.children
+        if isinstance(list_item, nodes.list_item)
+    ]
 
 
 @_process_node_to_blocks.register
@@ -312,6 +287,32 @@ def _(node: nodes.tip, *, section_level: int) -> list[NotionObject[Any]]:
     return _create_admonition_callout(node=node, emoji="💡", color=Color.GREEN)
 
 
+@_process_node_to_blocks.register
+def _(node: CollapseNode, *, section_level: int) -> list[NotionObject[Any]]:
+    """
+    Process collapse nodes by creating Notion ToggleItem blocks.
+    """
+    del section_level
+
+    children_to_process = node.children
+    title_text = node.attributes["label"]
+    toggle_block = UnoToggleItem(text=title_text)
+
+    for child in children_to_process:
+        for child_block in list(
+            _process_node_to_blocks(
+                child,
+                section_level=1,
+            )
+        ):
+            # Add nested blocks as children to the toggle
+            # Remove pyright ignore once we have
+            # https://github.com/ultimate-notion/ultimate-notion/issues/94.
+            toggle_block.obj_ref.value.children.append(child_block.obj_ref)  # pyright: ignore[reportUnknownMemberType]
+
+    return [toggle_block]
+
+
 def _map_pygments_to_notion_language(*, pygments_lang: str) -> CodeLang:
     """
     Map ``Pygments`` language names to Notion CodeLang ``enum`` values.
@@ -499,23 +500,6 @@ class NotionTranslator(NodeVisitor):
             section_level=self._section_level,
         )
         self._blocks.extend(blocks)
-
-    def depart_bullet_list(self, node: nodes.Element) -> None:
-        """
-        Handle leaving bullet list nodes.
-        """
-        assert self
-        del node
-
-    def visit_list_item(self, node: nodes.Element) -> None:
-        """
-        Handle list item nodes by creating Notion BulletedItem blocks.
-        """
-        blocks = _process_node_to_blocks(
-            node,
-            section_level=self._section_level,
-        )
-        self._blocks.extend(blocks)
         raise nodes.SkipNode
 
     def visit_topic(self, node: nodes.Element) -> None:
@@ -565,6 +549,18 @@ class NotionTranslator(NodeVisitor):
 
         raise nodes.SkipNode
 
+    def visit_CollapseNode(self, node: nodes.Element) -> None:  # pylint: disable=invalid-name  # noqa: N802
+        """
+        Handle collapse nodes by creating Notion ToggleItem blocks.
+        """
+        blocks = _process_node_to_blocks(
+            node,
+            section_level=self._section_level,
+        )
+        self._blocks.extend(blocks)
+
+        raise nodes.SkipNode
+
     def visit_document(self, node: nodes.Element) -> None:
         """
         Initialize block collection at document start.
@@ -609,4 +605,5 @@ def setup(app: Sphinx) -> ExtensionMetadata:
     """
     app.add_builder(builder=NotionBuilder)
     app.set_translator(name="notion", translator_class=NotionTranslator)
+
     return {"parallel_read_safe": True}
