@@ -32,6 +32,9 @@ from ultimate_notion.blocks import (
 from ultimate_notion.blocks import (
     TableOfContents as UnoTableOfContents,
 )
+from ultimate_notion.blocks import (
+    ToggleItem as UnoToggleItem,
+)
 from ultimate_notion.core import NotionObject
 from ultimate_notion.obj_api.core import GenericObject
 from ultimate_notion.obj_api.enums import CodeLang, Color
@@ -62,12 +65,14 @@ def _assert_rst_converts_to_notion_objects(
     expected_objects: list[NotionObject[Any]],
     make_app: Callable[..., SphinxTestApp],
     tmp_path: Path,
+    extensions: tuple[str, ...] = ("sphinx_notion",),
 ) -> None:
     """
     The given rST content is converted to the given expected objects.
     """
     srcdir = tmp_path / "src"
     srcdir.mkdir()
+
     (srcdir / "conf.py").write_text(data="")
 
     cleaned_content = textwrap.dedent(text=rst_content).strip()
@@ -77,7 +82,7 @@ def _assert_rst_converts_to_notion_objects(
         srcdir=srcdir,
         builddir=tmp_path / "build",
         buildername="notion",
-        confoverrides={"extensions": ["sphinx_notion"]},
+        confoverrides={"extensions": list(extensions)},
     )
     app.build()
 
@@ -889,39 +894,81 @@ def test_admonition_with_code_block_first(
     )
 
 
+def test_admonition_with_bullet_points(
+    make_app: Callable[..., SphinxTestApp],
+    tmp_path: Path,
+) -> None:
+    """
+    Test that bullet points show up within admonitions (issue #78).
+    """
+    rst_content = """
+        .. note::
+
+           This is an important note that demonstrates the note admonition
+           support.
+
+           * A
+           * B
+    """
+
+    callout = UnoCallout(text="", icon=Emoji(emoji="📝"), color=Color.BLUE)
+    callout.rich_text = text(
+        text="This is an important note that demonstrates the note "
+        "admonition\nsupport."
+    )
+
+    bullet_a = UnoBulletedItem(text="A")
+    bullet_b = UnoBulletedItem(text="B")
+
+    callout.obj_ref.value.children.append(bullet_a.obj_ref)  # pyright: ignore[reportUnknownMemberType]
+    callout.obj_ref.value.children.append(bullet_b.obj_ref)  # pyright: ignore[reportUnknownMemberType]
+
+    expected_objects: list[NotionObject[Any]] = [
+        callout,
+    ]
+
+    _assert_rst_converts_to_notion_objects(
+        rst_content=rst_content,
+        expected_objects=expected_objects,
+        make_app=make_app,
+        tmp_path=tmp_path,
+    )
+
+
 def test_nested_bullet_list(
     make_app: Callable[..., SphinxTestApp],
     tmp_path: Path,
 ) -> None:
     """
-    Test that nested bullet lists are converted to Notion BulletedItem blocks
-    with proper nesting structure (limited to 2 levels).
+    Test that deeply nested bullet lists work.
     """
     rst_content = """
-        * Top level item 1
-        * Top level item 2 with children
+        * Top level item
+        * Top level with children
 
-          * Second level item 1
-          * Second level item 2
+          * Second level item
+          * Second level with children
 
-        * Top level item 3
+            * Third level item (now allowed!)
+
+        * Another top level item
     """
 
-    # Create nested bullet structure with only 2 levels
-    # Second level items (no children allowed at this level)
-    second_level_1 = UnoBulletedItem(text="Second level item 1")
-    second_level_2 = UnoBulletedItem(text="Second level item 2")
+    third_level_1 = UnoBulletedItem(text="Third level item (now allowed!)")
+
+    second_level_1 = UnoBulletedItem(text="Second level item")
+    second_level_2 = UnoBulletedItem(text="Second level with children")
+
+    top_level_1 = UnoBulletedItem(text="Top level item")
+    top_level_2 = UnoBulletedItem(text="Top level with children")
 
-    # Top level items
-    top_level_1 = UnoBulletedItem(text="Top level item 1")
-    top_level_2 = UnoBulletedItem(text="Top level item 2 with children")
-    # Add second level children to top level item 2
     # Remove pyright ignore once we have
     # https://github.com/ultimate-notion/ultimate-notion/issues/94.
+    second_level_2.obj_ref.value.children.append(third_level_1.obj_ref)  # pyright: ignore[reportUnknownMemberType]
     top_level_2.obj_ref.value.children.append(second_level_1.obj_ref)  # pyright: ignore[reportUnknownMemberType]
     top_level_2.obj_ref.value.children.append(second_level_2.obj_ref)  # pyright: ignore[reportUnknownMemberType]
 
-    top_level_3 = UnoBulletedItem(text="Top level item 3")
+    top_level_3 = UnoBulletedItem(text="Another top level item")
 
     expected_objects: list[NotionObject[Any]] = [
         top_level_1,
@@ -934,35 +981,53 @@ def test_nested_bullet_list(
         expected_objects=expected_objects,
         make_app=make_app,
         tmp_path=tmp_path,
+        extensions=("sphinx_notion", "sphinx_toolbox.collapse"),
     )
 
 
-def test_nested_bullet_list_error_on_excessive_depth(
+def test_collapse_block(
+    *,
     make_app: Callable[..., SphinxTestApp],
     tmp_path: Path,
 ) -> None:
     """
-    Test that an error is raised when bullet lists exceed the 2-level limit.
+    Test that collapse directives convert to Notion ToggleItem blocks.
     """
     rst_content = """
-        * Top level item
-        * Top level with children
+        Regular paragraph.
 
-          * Second level item
-          * Second level with children
+        .. collapse:: Click to expand
 
-            * Third level item (should cause error)
+           This content is hidden by default.
 
-        * Another top level item
+           It supports **formatting**.
+
+        Another paragraph.
     """
 
-    expected_message = (
-        "Nested bullet point at depth 3 exceeds Notion API limit of 2 levels."
+    toggle_block = UnoToggleItem(text="Click to expand")
+
+    nested_para1 = UnoParagraph(text="This content is hidden by default.")
+    nested_para2 = UnoParagraph(text="It supports formatting.")
+    nested_para2.rich_text = (
+        text(text="It supports ", bold=False)
+        + text(text="formatting", bold=True)
+        + text(text=".", bold=False)
+    )
+
+    toggle_block.obj_ref.value.children.append(nested_para1.obj_ref)  # pyright: ignore[reportUnknownMemberType]
+    toggle_block.obj_ref.value.children.append(nested_para2.obj_ref)  # pyright: ignore[reportUnknownMemberType]
+
+    expected_objects: list[NotionObject[Any]] = [
+        UnoParagraph(text="Regular paragraph."),
+        toggle_block,
+        UnoParagraph(text="Another paragraph."),
+    ]
+
+    _assert_rst_converts_to_notion_objects(
+        rst_content=rst_content,
+        expected_objects=expected_objects,
+        make_app=make_app,
+        tmp_path=tmp_path,
+        extensions=("sphinx_notion", "sphinx_toolbox.collapse"),
     )
-    with pytest.raises(expected_exception=ValueError, match=expected_message):
-        _assert_rst_converts_to_notion_objects(
-            rst_content=rst_content,
-            expected_objects=[],
-            make_app=make_app,
-            tmp_path=tmp_path,
-        )
